// set the dimensions and margins of the graph
const margin = {
    top: 20,
    right: 30,
    bottom: 60,
    left: 80,
  },
  width = 940 - margin.left - margin.right,
  height = 480 - margin.top - margin.bottom;

const label = 'Year';

// append the svg object to the body of the page
const svg = d3
  .select('#my_dataviz')
  .append('svg')
  .attr(
    'width',
    width + margin.left + margin.right
  )
  .attr(
    'height',
    height + margin.top + margin.bottom
  )
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left}, ${margin.top})`
  );

// Parse the Data
d3.csv(
  'https://gist.githubusercontent.com/Snarasimhap/24a15c327e095b6862cc098faba79faa/raw/eadf4240bbbc0135dc4d90013220096b8d3b149f/7s.csv'
).then(function (data) {
  // List of groups = header of the csv files
  const keys = data.columns.slice(1);

  // Add X axis
  const x = d3
    .scaleTime()
    .domain(d3.extent(data, (d) => d.Science))
    .range([0, width]);
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(
      d3
        .axisBottom(x)
        .ticks(5)
        .tickFormat(d3.format('d'))
    );

  // Add Y axis
  const y = d3
    .scaleLinear()
    .domain([0, 200000])
    .range([height, 0]);
  svg.append('g').call(d3.axisLeft(y));

  // color palette
  const color = d3
    .scaleOrdinal()
    .domain(keys)
    .range([
      '#92a8d1',
      '#034f84',
      '#f7cac9',
      '#f7786b',
      '#eea29a',
      '#c94c4c',
      '#b1cbbb',
      '#5e7881',
    ]);

  //stack the data?
  const stackedData = d3.stack().keys(keys)(data);

  // Show the areas
  svg
    .selectAll('mylayers')
    .data(stackedData)
    .join('path')
    .style('fill', function (d) {
      return color(d.key);
    })
    .attr('d',d3.area()
        .x(function (d, i) {
          return x(d.data.year);
        })
        .y0(function (d) {
          return y(d[0]);
        })
        .y1(function (d) {
          return y(d[1]);
        })
    );

  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', height + 38)
    .text('Year')
    .style('font-size', '29px')
    .attr('font-family', 'Lucida Console')
    .attr('fill', '#616161');

  svg
    .append('text')
    .attr('x', -height / 4)
    .attr('y', -50)
    .attr('text-anchor', 'end')
    .attr('transform', 'rotate(270)')
    .text('Points??')
    .style('font-size', '29px')
    .attr('font-family', 'Lucida Console')
    .attr('fill', '#616161');
});
